# BEGIN COPYRIGHT BLOCK
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# (C) 2007 Red Hat, Inc.
# All rights reserved.
# END COPYRIGHT BLOCK

###############################################################################
###                          D E F I N I T I O N S                          ###
###############################################################################

## Entity Definitions
%define base_entity       Red Hat
%define base_flavor       redhat
%define base_prefix       pki

## Product Definitions
%define base_system       Certificate System
%define base_product      Token Processing System
%define base_component    tps
%define base_pki          %{base_entity} %{base_system}

## Package Header Definitions
%define base_name         %{base_prefix}-%{base_component}
%define base_version      8.1.0
%define base_release      20
%define base_phase        %{nil}
%define base_group        System Environment/Daemons
%define base_vendor       Red Hat, Inc.
%define base_license      LGPLv2 with exceptions
%define base_packager     %{base_vendor} <http://bugzilla.redhat.com/bugzilla>
%define base_summary      %{base_pki} - %{base_product}
%define base_url          http://www.redhat.com/certificate_system

## Legacy Definitions
%define legacy_prefix     rhpki
%define legacy_name       %{legacy_prefix}-%{base_component}
%define legacy_tokendb    tus

## Build Definitions
%define base_build_dir    blds
%define base_staging_dir  STAGING

## Installation Definitions
%define base_install_dir  /usr
%define setup_package     setup_package

## Pre & Post Install/Uninstall Scripts Definitions
%define base_user         pkiuser
%define base_uid          17
%define base_gid          17
%define base_instance     /var/lib/%{base_name}

## Helper Definitions
%define pki_ca            %{base_entity} Certificate Authority
%define pki_drm           %{base_entity} Data Recovery Manager
%define pki_ds            %{base_entity} Directory Server
%define pki_ocsp          %{base_entity} Online Certificate Status Protocol Manager
%define pki_ra            %{base_entity} Registration Authority
%define pki_tks           %{base_entity} Token Key Service
%define pki_tps           %{base_entity} Token Processing System

## Don't build the debug packages
%define debug_package     %{nil}


##===================##
## Linux Definitions ##
##===================##
%ifos Linux
## For PKI version information, ALWAYS refer to the version of the
## Red Hat UI package dependency associated with this Red Hat spec file!
%define pki_version       %(echo `rpm -q --queryformat '%{VERSION}' %{base_flavor}-%{base_name}-ui`)

## 32-bit Definitions
%ifarch i386 i486 i586 i686
%define architecture      intel
%define configure_cmd     ../configure --libdir=%{base_install_dir}/lib
%endif

## 64-bit Definitions
%ifarch x86_64
%define architecture      intel
%define configure_cmd     ../configure --enable-64bit --libdir=%{base_install_dir}/lib64
%endif

## Disallow an initial login shell
## NOTE:  SELinux policy requires a shell of /sbin/nologin
%define base_login_shell  /sbin/nologin

## A distribution model is required on certain Linux operating systems!
##
## check for a pre-defined distribution model
%define undefined_distro  %(test "%{dist}" = "" && echo 1 || echo 0)
%if %{undefined_distro}
%define is_fedora         %(test -e /etc/fedora-release && echo 1 || echo 0)
%if %{is_fedora}
## define a default distribution model on Fedora Linux
%define dist_prefix       .fc
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/fedora-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%else
%define is_redhat         %(test -e /etc/redhat-release && echo 1 || echo 0)
%if %{is_redhat}
## define a default distribution model on Red Hat Linux
%define dist_prefix       .el
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/redhat-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%endif
%endif
%endif
%endif



###############################################################################
###                       P A C K A G E   H E A D E R                       ###
###############################################################################

Name:           %{base_name}
Version:        %{base_version}
Release:        %{base_release}%{?base_phase}%{?dist}
Summary:        %{base_summary}
Vendor:         %{base_vendor}
URL:            %{base_url}
License:        %{base_license}
Packager:       %{base_packager}
Group:          %{base_group}


## Without AutoReqProv: no, rpmbuild finds all sorts of crazy
## dependencies that we don't care about, and refuses to install
AutoReqProv:    no

BuildRoot:      %{_builddir}/%{name}-root


## NOTE:  This spec file may require a specific JDK, "gcc", and/or "gcc-c++"
##        packages as well as the "rpm" and "rpm-build" packages.
##
##        Technically, "ant" should not need to be in "BuildRequires" since
##        it is the Java equivalent of "make" (and/or "Autotools").
##
BuildRequires:  apr-devel >= 1.2.7, apr-util-devel >= 1.2.7, %{base_flavor}-%{base_name}-ui >= 8.1.0, bash >= 3.2, cyrus-sasl-devel >= 2.1.22, httpd-devel >= 2.2.3, mozldap-devel >= 6.0.5, nspr-devel >= 4.8.6, nss-devel >= 3.12.8, pcre-devel >= 6.6, svrcore-devel >= 4.0.4, zlib >= 1.2.3, zlib-devel >= 1.2.3, nuxwdog-devel >= 1.0.1

## Without Requires something, rpmbuild will abort!
Requires:       %{base_prefix}-setup >= 8.1.0, %{base_name}-ui, mod_nss >= 1.0.8, mod_perl >= 2.0.4, mod_revocator >= 1.0.3, mozldap >= 6.0.5, perl-HTML-Parser, perl-HTML-Tagset, perl-Parse-RecDescent, perl-URI, perl-XML-NamespaceSupport, perl-XML-Parser, %{base_prefix}-selinux >= 8.1.0, perl-XML-Simple, nuxwdog >= 1.0.1, nuxwdog-devel >= 1.0.1, perl-Mozilla-LDAP
Provides:       %{legacy_name}
Obsoletes:      %{legacy_name}


## This package is non-relocatable!
#Prefix:

Source0:        %{base_name}-%{base_version}.tar.gz

## This package currently contains no patches!
#Patch0:


%description
%{base_pki} is an enterprise software system designed
to manage enterprise Public Key Infrastructure (PKI) deployments.

The %{pki_tps} is an optional PKI subsystem
that acts as a Registration Authority (RA) for authenticating and processing
enrollment requests, PIN reset requests, and formatting requests from the
Enterprise Security Client (ESC).

%{pki_tps} is designed to communicate with tokens that
conform to Global Platform's Open Platform Specification.

%{pki_tps} communicates over SSL with various
PKI backend subsystems (including the %{pki_ca},
the %{pki_drm}, and the %{pki_tks}) to
fulfill the user's requests.

%{pki_tps} also interacts with the token database,
an LDAP server that stores information about individual tokens.



###############################################################################
###                  P R E P A R A T I O N   &   S E T U P                  ###
###############################################################################

## On Linux systems, prep and setup expect there to be a Source file
## in the /usr/src/redhat/SOURCES directory - it will be unpacked
## in the _builddir (not BuildRoot)
%prep


%setup -q -n %{base_name}-%{base_version}


## This package currently contains no patches!
#%patch0
# patches



###############################################################################
###                        B U I L D   P R O C E S S                        ###
###############################################################################

%build
%{?pkg_config_cmd}
mkdir %{base_build_dir}
cd %{base_build_dir}
mkdir %{base_staging_dir}
%{configure_cmd}
make



###############################################################################
###                 I N S T A L L A T I O N   P R O C E S S                 ###
###############################################################################

%install
%{?pkg_config_cmd}
rm -rf ${RPM_BUILD_ROOT}
cd %{base_build_dir}
make install DESTDIR="`pwd`/%{base_staging_dir}"

## rearrange files to be in the desired native packaging layout
../%{setup_package} ${RPM_BUILD_ROOT} %{base_prefix} %{base_component} %{version} %{base_release} %{architecture} `pwd`/%{base_staging_dir}
 
## add EULA to the appropriate native packaging location
cp -p ../EULA ${RPM_BUILD_ROOT}%{_datadir}/doc/%{base_name}-%{base_version}/
chmod 00644 ${RPM_BUILD_ROOT}%{_datadir}/doc/%{base_name}-%{base_version}/EULA

## apply correct product version to CS.cfg
sed -i 's/^preop.product.version=.*$/preop.product.version=%{pki_version}/' ${RPM_BUILD_ROOT}/usr/share/%{base_prefix}/%{base_component}/conf/CS.cfg


###############################################################################
###                      C L E A N U P   P R O C E S S                      ###
###############################################################################

%clean
rm -rf ${RPM_BUILD_ROOT}



###############################################################################
###  P R E  &  P O S T   I N S T A L L / U N I N S T A L L   S C R I P T S  ###
###############################################################################

%pre
if [ `grep -c %{base_user} /etc/group` -eq 0 ] ; then
	echo "Adding default PKI group \"%{base_user}\" (gid=%{base_gid}) to /etc/group."
	groupadd -g %{base_gid} -r %{base_user}
	if [ $? -ne 0 ]; then
		echo "Adding default PKI group \"%{base_user}\" (gid=random) to /etc/group."
		groupadd %{base_user}
	fi
fi
if [ `grep -c %{base_user} /etc/passwd` -eq 0 ] ; then
	echo "Adding default PKI user \"%{base_user}\" (uid=%{base_uid}) to /etc/passwd."
	useradd -g %{base_user} -d %{_datadir}/%{base_prefix} -s %{base_login_shell} -c "%{base_pki}" -u %{base_uid} -r -m %{base_user}
	if [ $? -ne 0 ]; then
		echo "Adding default PKI user \"%{base_user}\" (uid=random) to /etc/passwd."
		useradd -g %{base_user} -d %{_datadir}/%{base_prefix} -s %{base_login_shell} -c "%{base_pki}" -m %{base_user}
	fi
fi
if [ "$1" -gt 1 ]; then
    backup_dir="%{_datadir}/%{base_prefix}/`rpm -q pki-tps|cut -c5-`"
    if [ -e $backup_dir ]; then
        rm -rf $backup_dir
    fi

    cp -rf %{_datadir}/%{base_prefix}/%{base_component}  $backup_dir
fi


## This package currently contains no post-installation process!
#%post


%preun
if [ -d %{base_instance} ] ; then
	echo "WARNING:  The default instance \"%{base_instance}\" was NOT removed!"
	echo ""
	echo "NOTE:  This means that the data in the default instance called"
	echo "       \"%{base_instance}\" will NOT be overwritten once the"
	echo "       \"%{name}\" package is re-installed."
	echo ""
	echo "Shutting down the default instance \"%{base_instance}\""
	echo "PRIOR to uninstalling the \"%{name}\" package:"
	echo ""
	/etc/init.d/%{base_name} stop
fi


## This package currently contains no post-uninstallation process!
#%postun



###############################################################################
###   I N V E N T O R Y   O F   F I L E S   A N D   D I R E C T O R I E S   ### 
###############################################################################

%files
%attr(-,root,root)     /etc/httpd/modules/*
%attr(00755,root,root) %{_bindir}/*
%attr(-,root,root)     %{_libdir}/*
%attr(-,root,root)     %{_datadir}/doc/%{base_name}-%{base_version}/*
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/alias
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/applets
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/cgi-bin
%attr(00660,root,root) %{_datadir}/%{base_prefix}/%{base_component}/conf/CS.cfg
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/conf/[a-z]*
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/docroot
%attr(00755,root,root) %{_datadir}/%{base_prefix}/%{base_component}/docroot/index.cgi
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/etc
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/lib
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/logs
%attr(00770,root,root) %{_datadir}/%{base_prefix}/%{base_component}/logs/signedAudit
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/samples
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/scripts
%attr(-,root,root)     %{_datadir}/%{base_prefix}/%{base_component}/setup



###############################################################################
###                            C H A N G E L O G                            ###
###############################################################################

%changelog
* Fri Jan  6 2012 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-20
- Bugzilla Bug #772312 - 32-bit TPS libraries are not being built in the
  proper location

* Thu Jan  5 2012 Christina Fu <cfu@redhat.com> 8.1.0-19
- Bugzilla Bug #769739 - CC: self test verifySystemCertByNickname: certain
  failure will not cause server to shutdown as expected (changed variable name)

* Wed Jan  4 2012 Christina Fu <cfu@redhat.com> 8.1.0-18
- Bugzilla Bug #769739 - CC: self test verifySystemCertByNickname: certain
  failure will not cause server to shutdown as expected

* Tue Jan  3 2012 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-17
- Bugzilla Bug #512239 - Examine bogus-looking RPATH in TPS . . .

* Tue Sep 27 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-16
- Bugzilla Bug #737184 - TPS UI display admin user name as
  "undefined TUS Administrator". (awnuk)
- Bugzilla Bug #735191 - in ou=tokens, token_type not getting updated
  if a card is changed from one type to another (awnuk)
- Bugzilla Bug #741795 - SSL Ldap connection test at startup fails under
  FIPS mode. (jmagne)

* Fri Sep 16 2011 Jack Magne <jmagne@redhat.com> 8.1.0-15
- Bugzilla Bug #730162 - TPS/TKS token enrollment failure in FIPS mode
  (hsm+NSS). (jmagne)

* Wed Sep 7 2011 Ade Lee <alee@redhat.com> 8.1.0-14
- Bugzilla Bug #733446 - In-place upgrade - Upgrading nuxwdog packages throws error,
  updated nuxwdog dependencies

* Thu Aug 11 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-13
- Bugzilla Bug #725572 - Starting TPS subsystem with no pre-existing
  audit log file does not write audit messages. (jmagne)
- Bugzilla Bug #724848 - CC_LAB_EVAL: none-FIPS ciphers allowed in CC mode
  (cfu)

* Wed Jul 6 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-12
- Bugzilla Bug #717813 - EV_AUDIT_LOG_SHUTDOWN audit log not generated
  for tps and ca on server shutdown (alee, jmagne)
- Bugzilla Bug #717765 - TPS configuration: logging into security domain
  from tps does not work with clientauth=want (alee)

* Wed May 25 2011 Ade Lee <alee@redhat.com> 8.1.0-11
- Bugzilla Bug #707095 - tps delete user operation should check for roles
  (not have them passed in) (alee)

* Tue May 17 2011 Jack Magne <jmagne@redhat.com> 8.1.0-10
- Bugzilla Bug #696443 - ESC display Smartcard renewal operation success
  for a failed renewal operation.

* Sat Apr 16 2011 Jack Magne <jmagne@redhat.com> 8.1.0-9
- Bugzilla Bug #696851 - TPS crashes that cause AuditVerify
  on TPS audit logs - some of the signatures are failing.

* Fri Apr 15 2011 Ade Lee <alee@redhat.com> 8.1.0-8
- Bugzilla Bug #694569 - parameter used by pkiremove not updated
- Bugzilla Bug #697035 - TPS database schema not populated correctly

* Fri Apr 8 2011 Ade Lee <alee@redhat.com> 8.1.0-7
- Bugzilla Bug #694486 - TPS Install doesn't set the right trust for
  audit signing cert.
- Bugzilla Bug #694505 - TPS Configuration with nethsm: CS.cfg has
  nicknames with "NHSM6000-OCS:" printed twice.

* Wed Mar 30 2011 Ade Lee <alee@redhat.com> 8.1.0-6
- Bugzilla Bug #691867 - Change to perl-Mozilla-LDAP for ldaps support

* Thu Mar 24 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-5
- Bugzilla Bug #690646 - Update Build and Runtime Dependencies for RHCS 8.1

* Thu Mar 17 2011 Ade Lee <alee@redhat.com> 8.1.0-4
- Bugzilla Bug #684871 - Add perl_LDAP dependency for ldaps support

* Wed Jan 26 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-3
- Bugzilla Bug #588460 - Add new 'mod_revocator' runtime dependency to RA and
  TPS . . .

* Tue Dec 14 2010 Ade Lee <alee@redhat.com> 8.1.0-2
- Bugzilla Bug #663116 - Update nuxwdog dependencies

* Tue Jan 12 2010 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-1
- Bump to version 8.1.0

* Mon Nov 9 2009 Ade Lee <alee@redhat.com> 8.0.0-30
- Bugzilla Bug #518123 - Prompt for passwords if password.conf is removed
- Bugzilla Bug #529280 - TPS returns HTTP data without ending in 0rn per RFC 2616.
- Bugzilla Bug #Bug 533510 -  rhcs80 tps exception, cannot start when signed audit true.

* Thu Jul 16 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-29
- Bugzilla Bug #512134 -  strip symbols from libraries, modules,
  and executables
- Release Candidate 4a build

* Mon Jul 13 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-28
- Bugzilla Bug #511136 -  Integrate EULA file into RHCS
- Release Candidate 4 build

* Wed Jul 8 2009 Kevin Wright <kwright@redhat.com> 8.0.0-27
- Bugzilla Bug #510352 -  Release Candidate 3 build

* Mon Jul 6 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-26
- bugzilla Bug #509183 -  update nss dependency >= 3.12.3.99

* Thu Jul 2 2009 Kevin Wright <kwright@redhat.com> 8.0.0-25
- Bugzilla Bug #509447 -  Release Candidate 2 build

* Thu Jun 25 2009 Kevin Wright <kwright@redhat.com> 8.0.0-24
- Bugzilla Bug #508179 -  Remove base_phase ".beta" tag

* Fri Jun 19 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-23
- Bugzilla Bug #506867 -  Provide custom error page for HTTP STATUS 500

* Mon Jun 15 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-22
- Bugzilla Bug #502908 -  Current page not found handling is a Cat 2 finding
  with the Tomcat STIG

* Mon Jun 8 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-21
- Bugzilla Bug #501081 -  remove mod_revocator rpm as a dependency

* Sat May 30 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-20
- Bugzilla Bug #476782 -  Create "pkiuser" with a predetermined
  system "UID" and "GID" . . .

* Mon May 4 2009 Kevin Wright <kwright@redhat.com> 8.0.0-19
- Bugzilla Bug #499030 -  Beta 2 Release

* Thu Apr 16 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-18
- Bugzilla Bug #495959 -  pkiremove requires "perl-XML-SAX" as a runtime
  dependency

* Sat Mar 28 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-17
- Bugzilla Bug #492180 -  Security officer: token recovery for a security
  officer throws error 28 'connection to server lost'.
- Bugzilla Bug #492503 -  Integrate "mod_revocator" as a runtime dependency
  for RA and TPS  

* Fri Mar 27 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-16
- Bugzilla Bug #492502 -  Redefine "base_phase" from ".alpha" to ".beta"

* Wed Mar 18 2009 Christina Fu <cfu@redhat.com> 8.0.0-15
- Bugzilla Bug # 485166 - Signed Audit Feature for TPS

* Wed Mar 11 2009 Ade Lee <alee@redhat.com> 8.0.0-14
  Bugzilla Bug #489712 RA and TPS need perl-XML-Simple as prereq

* Fri Mar 6 2009 Ade Lee <alee@redhat.com> 8.0.0-13
- Bugzilla Bug 472308 - web installer display wrong product version in first Welcome panel

* Sat Feb 28 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-12
- Bugzilla Bug #487896 - Introduce optional 'base_phase' release tag to
  denote ".alpha", ".beta", etc.

* Wed Feb 25 2009 Jack magne <jmagne@redhat.com> 8.0.0-11
- Bugzilla #445274 - Make esc security officer mode work.
* Tue Feb 17 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-10
- Bugzilla Bug #485790 -  Need changes made to spec files in various packages
  to be able to build in koji/brew

* Sat Feb 14 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-9
- Bugzilla Bug #250874 -Change spec file dependencies to rely on latest
  versions of components (NSPR, NSS, JSS, MOD_NSS)

* Tue Jan 27 2009 Ade Lee <alee@redhat.com> 8.0.0-8
- Bugzilla Bug 480679 - Integrate selinux into framework

* Thu Jan 22 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-7
- Bugzilla Bug #480952 - moved "perl-XML-Simple" and "perl-libwww-perl"
  runtime dependencies to pki-setup

* Wed Dec 10 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-6
- Bugzilla Bug #475895 - Parameterize the initial login shell

* Thu Dec 4 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-5
- Bugzilla Bug #474369 - Remove NSS dependency on "pkcs11-devel" and
                         upgrade NSS/NSPR version dependencies  

* Sat Nov 29 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-4
- Aligned RHEL 5, RHEL 4, and Solaris 9 "base_release" numbers
- Bugzilla Bug #445402 - Changed "base_url" from
                         "http://www.redhat.com/software/rha/certificate" to
                         "http://www.redhat.com/certificate_system"

* Sat Nov 22 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-3
- Bugzilla Bug #472305 - "equality" tests in all spec files need to be fixed
- Bumped "java" and "java-devel" 1.4.2 and 1.5.0 dependencies to 1.6.0
- Changed "java-sdk" to "java-devel" for consistency

* Fri Jun 8 2007 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-2
- bugzilla bug #243480 - added legacy upgrade path

* Tue Jun 5 2007 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-1
- bugzilla bug #242575 - Made numerous changes to spec file.

* Fri May 04 2007 Kevin McCarthy <kmccarth@redhat.com> 7.3.0-16
- Fix for RHEL5.

* Fri Apr 27 2007 Thomas Kwan <mharmsen@redhat.com> 7.3.0-15
- bugzilla #237397 - fixed logic to perform ldapsearch

* Mon Apr 23 2007 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-14
- bugzilla #237397 - Made ldapsearch variable platform-dependent.

* Thu Apr 19 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-13
- bugzilla #237059 - Changed License to LGPL

* Tue Apr 17 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-12
- bugzilla #209518 - fixed default token name format

* Mon Apr 16 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-11
- bugzilla #236667 - invalid phone home URL for userKey

* Thu Apr 12 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-10
- Created internal security officer

* Wed Apr 11 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-9
- Allowed Upper case subject DN in cfg.pl

* Mon Apr 9 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-8
- Removed hard-coded password.
- Bumped Release Number.

* Thu Apr 5 2007 Thomas Kwan <nkwan@redhat.com> 7.3.0-7
- Fixed javascript problem in security officer workstation UI

* Thu Apr 5 2007 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-6
- Updated LICENSE file.
- Bumped Release Number.

* Mon Mar 19 2007 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-5
- Made package URL contingent upon distribution.
- Removed legacy RCS/SCCS version and release information.
- Bumped Release Number.

* Fri Mar 9 2007 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-4
- Updated to NSPR 4.6.6 and NSS 3.11.5.
- Bumped Release Number.

* Fri Mar 2 2007 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-3
- Eliminated Autotool warnings.
- Bumped Release Number.

* Thu Mar 1 2007 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-2
- Created build and installation directories.
- Bumped Release Number.

* Tue Feb 6 2007 Matthew Harmsen <mharmsen@redhat.com> 7.3.0-1
- Initial combined RPM and PKG spec file.

